#!/usr/bin/python
# -*- coding: utf-8 -*-

from Screens.Screen import Screen
from Components.Label import Label
from Components.VideoWindow import VideoWindow
from Components.SystemInfo import SystemInfo
from Components.config import config
from enigma import getDesktop, ePoint, eSize, eServiceReference, eServiceCenter, eTimer, iPlayableService, iServiceInformation, getBestPlayableServiceReference
from os import path as os_path


class ChannelSelectionPiP(Screen):
	skin ="""
		<screen position="0,0" size="320,280">
			<widget name="video" position="0,0" size="320,280" />
		</screen>"""
	
	def __init__(self, session, args =None):
		self.session = session
		Screen.__init__(self, session)
		self["video"] = VideoWindow()
		self.onLayoutFinish.append(self.LayoutFinished)

	def LayoutFinished(self):
		self.onLayoutFinish.remove(self.LayoutFinished)
		self.instance.setTransparent(2)

	def move(self, x, y):
		self.instance.move(ePoint(x, y)) 

	def playService(self, service):
		if service and (service.flags & eServiceReference.isGroup):
			ref = getBestPlayableServiceReference(service, eServiceReference())
		else:
			ref = service
		if ref and not (ref.flags & (eServiceReference.isMarker|eServiceReference.isDirectory|eServiceReference.isGroup)):
			self.pipservice = eServiceCenter.getInstance().play(ref)
			if self.pipservice and not self.pipservice.setTarget(1):
				self.pipservice.start()
				self.currentService = service
				return True
			else:
				self.pipservice = None
		if ref and (ref.flags & (eServiceReference.isMarker|eServiceReference.isDirectory|eServiceReference.isGroup)):
			self.pipservice = None
		return False
		

ChannelSelectionBase_ori = None
from Screens.ChannelSelection import ChannelSelectionBase
ChannelSelectionBase_ori = ChannelSelectionBase.__init__

if os_path.exists("/usr/lib/enigma2/python/Plugins/Extensions/EPGSearch"):
	import Plugins.Extensions.EPGSearch.EPGSearch as EPGSearch
	ChannelSelectionBase_ori = EPGSearch.ChannelSelectionBase__init__
	
def ChannelSelectionBase__init__(self, session):
		
		ChannelSelectionBase_ori(self, session)
		
		#for pipzap
		self.dopipzap = False
		self.enable_pipzap = False
		
		print "=== PiPChannelSelectionBase__init__", self.skinName
		
		self["pipvideo"] = Label("")
		self["pipvideo"].hide()
		self.session.pip1 = None
		
		if self.skinName != "ChannelSelectionRadio":
		
			#live edit pip screen =====
			from skin import lookupScreen
			
			myscreen, path = lookupScreen(self.skinName, getDesktop(0).getStyleID())
			try:
				if myscreen:
					from xml.etree import ElementTree
					xml_str = ElementTree.tostring(myscreen)
				elif self.skin:
					xml_str = self.skin
				if not 'name="pipvideo"' in xml_str:
					xml_str = xml_str.replace(' name="' + self.skinName + '" ',' name="' + self.skinName + '_PiP" ')
					self.skinName = self.skinName + "_PiP"
					skinrows = xml_str.strip().split("\n")
					# add widget for pipvideo to skinscreen with pos/size from settings
					w = str(config.plugins.pipchannelselection.pipSizeWidth.value)
					h = str(config.plugins.pipchannelselection.pipSizeHeight.value)
					x = str(config.plugins.pipchannelselection.pipPosX.value)
					y = str(config.plugins.pipchannelselection.pipPosY.value)
					skinrow = '<widget name="pipvideo" position="'+ x +','+ y +'" size="'+ w + ','+ h + '" zPosition="1000" backgroundColor="transparent" />'
					skinrows.insert(len(skinrows)-1,skinrow)
					xml_str = "\n".join(skinrows)
					self.skin = xml_str # set new skinscreen to screen
			except:
				import traceback
				traceback.print_exc()
			#== ende live edit screen =============================
			
			if (SystemInfo.get("NumVideoDecoders", 1) > 1):
				self["list"].onSelectionChanged.append(self.selectionChanged)
				self.onShown.append(self.onShown_ChannelSelection)
				self.onLayoutFinish.append(self.layoutFinished)
				self.onHide.append(self.onHide_ChannelSelection)
				self.xBoffset=-1
				self.yBoffset=-1
				self.firstPipStart = True
				self.hideScreen = True
		
def ChannelSelectionBase_onShown_ChannelSelection(self):
	print "=== onShown"#, self.mode
	if not config.plugins.pipchannelselection.enable.value:
		self["pipvideo"].hide()
		return
	if self.skinName == "ChannelSelectionRadio" or self.mode == 1: #MODE_RADIO:
		return
	self.hideScreen = False
	service = self.getCurrentSelection()
	if self["list"].mode != 1 or not service or (service.flags & (eServiceReference.isMarker|eServiceReference.isDirectory|eServiceReference.isGroup)):
		return # exit if not channel from fav-list
	if self.firstPipStart:
		self.firstPipStart=False
	self.showPiP()
	
def ChannelSelectionBase_onHide_ChannelSelection(self):
	print "=== onHide"
	self.hideScreen = True
	if hasattr(self.session,"pip1") and self.session.pip1:
		self.hidePiP()

def ChannelSelectionBase_layoutFinished(self):
	print "=== ChannelSelectBase layoutFinished"
	self.onLayoutFinish.remove(self.layoutFinished)
	#save org position of pipvideo from skinscreen
	self.videopipPosX = self["pipvideo"].instance.position().x()
	self.videopipPosY = self["pipvideo"].instance.position().y()

def ChannelSelectionBase_hidePiP(self):
	self.session.pip1.pipservice = None
	self["pipvideo"].hide()

def ChannelSelectionBase_showPiP(self):
	print "=== showPiP"
	if self.hideScreen:
		return
	service = self.getCurrentSelection()
	if self["list"].mode != 1 or not service or (service.flags & (eServiceReference.isMarker|eServiceReference.isDirectory|eServiceReference.isGroup)):
		self["pipvideo"].hide()
		return # exit if not channel from fav-list
	#if open E2-pip then close
	if self.session.pipshown:
		#if pipzap-pip
		if self.dopipzap:
			self.session.pip.inactive()
			self.dopipzap = False
		self.session.pip.pipservice=None
		self.session.deleteDialog(self.session.pip)
		self.session.pip = None
		del self.session.pip
		self.session.pipshown = False
	
	self["pipvideo"].show()
	if not hasattr(self.session,"pip1"):
		self.session.pip1=None
	if not self.session.pip1:
		print "=== instantiateDialog"
		self.session.pip1 = self.session.instantiateDialog(ChannelSelectionPiP)
		self.session.pip1.neverAnimate()
		
	self.MoveResizePiP()
	self.session.pip1.show()
	if self.session.pip1.playService(service):
		self.session.pip1.servicePath = service.getPath()
	elif self.session.pip1:
		self.hidePiP()

def ChannelSelectionBase_MoveResizePiP(self):
	print "=== MoveResizePiP", self.session.pip1
	try:
		# set pip-size to size of screen-"video"-widget - calculate (HD/FHD) to SD(PiP)
		pipvideo_width = int(self["pipvideo"].instance.size().width() / float(getDesktop(0).size().width()) * 720)
		pipvideo_height = int(self["pipvideo"].instance.size().height() / float(getDesktop(0).size().height()) * 576)
		print "=== size", int(pipvideo_width), int(pipvideo_height)
		
		# set pip-pos to Position of screen-"video"-widget - calculate (HD/FHD) to SD(PiP)
		pipvideo_pos_x = (self.videopipPosX + self.instance.position().x()) / float(getDesktop(0).size().width()) * 720
		pipvideo_pos_y = (self.videopipPosY + self.instance.position().y())/ float(getDesktop(0).size().height()) * 576
		
		#save at first start the offset for calculate absolute position
		if self.xBoffset<0:
			self.xBoffset=0
			#check if screen is open without wfNoBorder
			if self.instance.csize().width() != self.instance.size().width():
				self.xBoffset = abs(self.session.pip1.instance.position().x())
				self.xBoffset = int(self.xBoffset / float(getDesktop(0).size().width()) * 720)
		if self.yBoffset<0:
			self.yBoffset=0
			if self.instance.csize().height() != self.instance.size().height():
				self.yBoffset = abs(self.session.pip1.instance.position().y())
				self.yBoffset = int(self.yBoffset / float(getDesktop(0).size().height()) * 576)
		print "=== pos, offset", int(pipvideo_pos_x), int(pipvideo_pos_y), int(self.xBoffset), int(self.yBoffset)
		self.session.pip1.move(int(pipvideo_pos_x + self.xBoffset),int(pipvideo_pos_y + self.yBoffset))
		self.session.pip1.instance.resize(eSize(*(pipvideo_width,pipvideo_height)))
		self.session.pip1["video"].instance.resize(eSize(*(pipvideo_width, pipvideo_height)))
	except:
		import traceback
		traceback.print_exc()

def ChannelSelectionBase_onClosePiP(self):
	print "=== closePiP"
	if self.session.pip1:
		self["pipvideo"].hide()
		self.session.pip1.pipservice=None
		self.session.deleteDialog(self.session.pip1)
		del self.session.pip1

def ChannelSelectionBase_selectionChanged(self):
	print "=== selectionChanged, mode", self.mode
	if not config.plugins.pipchannelselection.enable.value or self.firstPipStart or self.hideScreen:
		return
	service = self.getCurrentSelection()
	if self["list"].mode ==1 and service and not (service.flags & (eServiceReference.isMarker|eServiceReference.isDirectory|eServiceReference.isGroup)):
		self.onShown_ChannelSelection()
	elif self.session.pip1:
		self.hidePiP()

def ChannelSelectionBase_close(self, *retval):
	if hasattr(self.session,"pip1") and self.session.pip1:
		self.onClosePiP()
	self.session.close(self, *retval)

# Ende test pip =====================================================================


def overwriteFunctions():

	ChannelSelectionBase.__init__ = ChannelSelectionBase__init__
	if os_path.exists("/usr/lib/enigma2/python/Plugins/Extensions/EPGSearch"):
		EPGSearch.ChannelSelectionBase__init__ = ChannelSelectionBase__init__
	
	ChannelSelectionBase.onShown_ChannelSelection = ChannelSelectionBase_onShown_ChannelSelection
	ChannelSelectionBase.onClosePiP = ChannelSelectionBase_onClosePiP
	ChannelSelectionBase.onHide_ChannelSelection = ChannelSelectionBase_onHide_ChannelSelection
	ChannelSelectionBase.layoutFinished = ChannelSelectionBase_layoutFinished
	ChannelSelectionBase.hidePiP = ChannelSelectionBase_hidePiP
	ChannelSelectionBase.showPiP = ChannelSelectionBase_showPiP
	ChannelSelectionBase.MoveResizePiP = ChannelSelectionBase_MoveResizePiP
	ChannelSelectionBase.selectionChanged = ChannelSelectionBase_selectionChanged
	ChannelSelectionBase.close = ChannelSelectionBase_close
