#!/usr/bin/python
# -*- coding: utf-8 -*-

# GUI (System)
from enigma import getDesktop

# GUI (Screens)
from Screens.Screen import Screen
from Components.ConfigList import ConfigListScreen
from Screens.ChannelSelection import ChannelSelection, ChannelSelectionBase
import Screens.InfoBarGenerics
from Screens.InfoBar import InfoBar

# GUI (Summary)
from Screens.Setup import SetupSummary

# GUI (Components)
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.Label import Label

# Configuration
from Components.config import * 

PluginVersion = ""

sz_w = getDesktop(0).size().width()

class PiPChannelSelectionSetup(Screen, ConfigListScreen):
	
	if sz_w == 1920:
		skin = """
		<screen name="PiPChannelSelectionSetup" position="center,center" size="1200,820">
			<ePixmap pixmap="skin_default/buttons/red.png" position="10,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="305,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="600,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="895,5" size="295,70" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="10,5" zPosition="1" size="295,70" font="Regular;30" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="310,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="610,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_blue" render="Label" position="910,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget name="config" position="10,90" size="1180,540" enableWrapAround="1" scrollbarMode="showOnDemand" />
			<ePixmap pixmap="skin_default/div-h.png" position="10,650" zPosition="2" size="1180,2" />
			<widget name="help" position="10,655" size="1180,145" font="Regular;32" />
		</screen>"""
	else:
		skin = """
		<screen name="PiPChannelSelectionSetup" position="center,center" size="800,530">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="200,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="400,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="600,0" size="200,40" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="200,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="400,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_blue" render="Label" position="600,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget name="config" position="5,50" size="790,380" enableWrapAround="1" scrollbarMode="showOnDemand" />
			<ePixmap pixmap="skin_default/div-h.png" position="0,431" zPosition="2" size="800,2" />
			<widget name="help" position="5,435" size="790,75" font="Regular;22" />
		</screen>"""


	def __init__(self, session):
		Screen.__init__(self, session)

		# Summary
		global PluginVersion
		from plugin import VERSION
		PluginVersion = VERSION
		self.skinName = "PiPChannelSelectionSetup"
		self.setup_title = _("PiPChannelSelection Setup ") + str(PluginVersion)
		self.onChangedEntry = []
		
		self.list = []
		self.buildConfig()
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changed)
		
		def selectionChanged():
			if self["config"].current:
				self["config"].current[1].onDeselect(self.session)
			self["config"].current = self["config"].getCurrent()
			if self["config"].current:
				self["config"].current[1].onSelect(self.session)
			for x in self["config"].onSelectionChanged:
				x()
		self["config"].selectionChanged = selectionChanged
		self["config"].onSelectionChanged.append(self.updateHelp)

		# Initialize widgets
		self["key_green"] = StaticText(_("OK"))
		self["key_red"] = StaticText(_("Cancel"))
		self["key_yellow"] = StaticText("")
		self["key_blue"] = StaticText("")
		self["help"] = Label("")
		
		# Define Actions
		self["actions"] = ActionMap(["SetupActions", "ColorActions"],
			{
				"cancel": 	self.keyCancel,
				"save": 		self.save,
				#"save": 		self.keySave,
			},-2)

		# Trigger change
		self.changed()

		self.onLayoutFinish.append(self.layoutFinished)

	def buildConfig(self):
		
		self.list.append( getConfigListEntry(_("activate PiP for ChannelSelection"), config.plugins.pipchannelselection.enable, _("active the pip-window in the channelselection-screen")) )
		
		if config.plugins.pipchannelselection.enable.value:
			self.list.append( getConfigListEntry(_("select the x-Position of pip"), config.plugins.pipchannelselection.pipPosX, _("select the position of pip from left (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the top-position of pip"), config.plugins.pipchannelselection.pipPosY, _("select the position of pip from top (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the width of pip"), config.plugins.pipchannelselection.pipSizeWidth, _("select the width of pip (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the height of pip"), config.plugins.pipchannelselection.pipSizeHeight, _("select the height of pip (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )

	def layoutFinished(self):
		self.setTitle(self.setup_title)

	def setCustomTitle(self):
		self.setTitle(self.setup_title)

	def updateHelp(self):
		cur = self["config"].getCurrent()
		if cur:
			self["help"].text = cur[2]

	def changeConfig(self):
		self.list = []
		self.buildConfig()
		self["config"].setList(self.list)

	def changed(self):
		for x in self.onChangedEntry:
			x()
		current = self["config"].getCurrent()[1]
		if (current == config.plugins.pipchannelselection.enable):
			self.changeConfig()
		return

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		return SetupSummary
	
	def save(self):
		for x in self["config"].list:
			x[1].save()
		self.close()
		
		Screens.InfoBarGenerics.InfoBarChannelSelection.__init__(InfoBar.instance)
		
		#remove multiple __delChannelSelectionScreen in InfoBar.onClose
		try:
			count=0
			for fnc in InfoBar.instance.onClose:
				if fnc == InfoBar.instance._InfoBarChannelSelection__delChannelSelectionScreen:
					count+=1
				if count>1:
					InfoBar.instance.onClose.remove(InfoBar.instance._InfoBarChannelSelection__delChannelSelectionScreen)
					count-=1
		except:
			import traceback
			traceback.print_exc()
		
